==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/EatGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.entity.npc.NPCEntityImpl;
import cc.thonly.reverie_dreams.entity.skin.RoleSkins;
import cc.thonly.reverie_dreams.interfaces.IItemStack;
import net.minecraft.class_1268;
import net.minecraft.class_1352;
import net.minecraft.class_1799;
import net.minecraft.class_2392;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import net.minecraft.class_4174;
import net.minecraft.class_9323;
import net.minecraft.class_9334;

public class EatGoal extends class_1352 {
    private final NPCEntityImpl maid;
    int slot = -1;
    int dealyTick = 0;

    public EatGoal(NPCEntityImpl maid) {
//        this.setControls(EnumSet.of(Goal.Control.MOVE));
        this.maid = maid;
    }


    @Override
    public boolean method_6264() {
        if (RoleSkins.YUYUKO.get().equals(this.maid.getSkin())){
            return maid.getNutrition() < 20;
        }
        return (maid.getNutrition() < 20 && maid.method_6032() < 20) || maid.getNutrition() < 10;
    }

    @Override
    public void method_6269() {
        findFood();
    }

    @Override
    public void method_6268() {
        dealyTick--;
        class_3218 world = (class_3218) maid.method_37908();
        if (dealyTick <= 0) {
            method_6270();
            return;
        }
        if (slot == -1) {
            findFood();
            return;
        }
        class_1799 stack = maid.getInventory().getStack(slot);
        if (((IItemStack) (Object) stack).isFood()) {

            class_243 eyePos = maid.method_33571();

            //干饭粒子
            world.method_65096(
                    new class_2392(class_2398.field_11218, stack), // 粒子类型 + 物品
                    eyePos.field_1352 + maid.method_5720().field_1352 / 3.0, eyePos.field_1351, eyePos.field_1350 + maid.method_5720().field_1352 / 3.0,
                    2,
                    world.field_9229.method_43059() * 0.05, world.field_9229.method_43059() * 0.05, world.field_9229.method_43059() * 0.05
                    , world.field_9229.method_43059() * 0.05
            );
            //干饭声音
            if (dealyTick % 3 == 0) {
                maid.method_6104(class_1268.field_5808);
                world.method_60511(
                        null,
                        maid.method_23317(),
                        maid.method_23318(),
                        maid.method_23321(),
                        class_3417.field_20614,
                        class_3419.field_15256,
                        0.5F,
                        class_3532.method_32750(world.field_9229, 0.9F, 1.0F)
                );
            }
        } else findFood();
        super.method_6268();
    }


    @Override
    public void method_6270() {
        //double speed = maid.getAttributeBaseValue(EntityAttributes.MOVEMENT_SPEED);
        //maid.getAttributeInstance(EntityAttributes.MOVEMENT_SPEED).setBaseValue(speed*2);
        eat();
        dealyTick = 30;
        this.slot = -1;
        //重置槽位/延迟 避免重复吃 我不知道为啥他会调用2次stop
        super.method_6270();
    }

    private boolean findFood() {
        Integer slot = maid.getInventory().findSlot(stack -> ((IItemStack) (Object) stack).isFood());
        if (slot == null) {
            this.slot = -1;
            return false;
        } else {
            this.slot = slot;
            dealyTick = 30;
        }
        return true;
    }

    public void eat() {
        class_3218 world = (class_3218) maid.method_37908();
        if (dealyTick > 0 || slot == -1) {
            return;
        }
        class_1799 stack = maid.getInventory().getStack(slot);
        if (((IItemStack) (Object) stack).isFood()) {
            class_9323 components = stack.method_57353();
            class_4174 foodComponent = components.method_58694(class_9334.field_50075);
            if (foodComponent != null) {
                int nutritionValue = foodComponent.comp_2491();
                int saturationValue = Math.round(foodComponent.comp_2492());
                maid.setNutrition(maid.getNutrition() + nutritionValue);
                maid.setSaturation(maid.getSaturation() + saturationValue);
                stack.method_7934(1);
                world.method_43128(
                        null,
                        maid.method_23317(),
                        maid.method_23318(),
                        maid.method_23321(),
                        class_3417.field_19149,
                        class_3419.field_15256,
                        0.5F,
                        class_3532.method_32750(world.field_9229, 0.9F, 1.0F)
                );
            }
        }
    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/EatGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.entity.npc.BaseNPCLikeEntity;
import cc.thonly.reverie_dreams.registry.content.skin.GensokyoSkinTypes;
import net.minecraft.class_1268;
import net.minecraft.class_1352;
import net.minecraft.class_1799;
import net.minecraft.class_2392;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import net.minecraft.class_4174;
import net.minecraft.class_9323;
import net.minecraft.class_9334;
import cc.thonly.reverie_dreams.interfaces.IItemStack;

public class EatGoal extends class_1352 {
    private final BaseNPCLikeEntity maid;
    int slot = -1;
    int dealyTick = 0;

    public EatGoal(BaseNPCLikeEntity maid) {
//        this.setControls(EnumSet.of(Goal.Control.MOVE));
        this.maid = maid;
    }


    @Override
    public boolean method_6264() {
        if (GensokyoSkinTypes.YUYUKO.get().equals(this.maid.getSkin())){
            return maid.getNutrition() < 20;
        }
        return (maid.getNutrition() < 20 && maid.method_6032() < 20) || maid.getNutrition() < 10;
    }

    @Override
    public void method_6269() {
        findFood();
    }

    @Override
    public void method_6268() {
        dealyTick--;
        class_3218 world = (class_3218) maid.method_37908();
        if (dealyTick <= 0) {
            method_6270();
            return;
        }
        if (slot == -1) {
            findFood();
            return;
        }
        class_1799 stack = maid.getInventory().getItem(slot);
        if (((IItemStack) (Object) stack).isFood()) {

            class_243 eyePos = maid.method_33571();

            //干饭粒子
            world.method_65096(
                    new class_2392(class_2398.field_11218, stack), // 粒子类型 + 物品
                    eyePos.field_1352 + maid.method_5720().field_1352 / 3.0, eyePos.field_1351, eyePos.field_1350 + maid.method_5720().field_1352 / 3.0,
                    2,
                    world.field_9229.method_43059() * 0.05, world.field_9229.method_43059() * 0.05, world.field_9229.method_43059() * 0.05
                    , world.field_9229.method_43059() * 0.05
            );
            //干饭声音
            if (dealyTick % 3 == 0) {
                maid.method_6104(class_1268.field_5808);
                world.method_60511(
                        null,
                        maid.method_23317(),
                        maid.method_23318(),
                        maid.method_23321(),
                        class_3417.field_20614,
                        class_3419.field_15256,
                        0.5F,
                        class_3532.method_32750(world.field_9229, 0.9F, 1.0F)
                );
            }
        } else findFood();
        super.method_6268();
    }


    @Override
    public void method_6270() {
        //double speed = maid.getAttributeBaseValue(EntityAttributes.MOVEMENT_SPEED);
        //maid.getAttributeInstance(EntityAttributes.MOVEMENT_SPEED).setBaseValue(speed*2);
        eat();
        dealyTick = 30;
        this.slot = -1;
        //重置槽位/延迟 避免重复吃 我不知道为啥他会调用2次stop
        super.method_6270();
    }

    private boolean findFood() {
        Integer slot = maid.getInventory().findSlot(stack -> ((IItemStack) (Object) stack).isFood());
        if (slot == null) {
            this.slot = -1;
            return false;
        } else {
            this.slot = slot;
            dealyTick = 30;
        }
        return true;
    }

    public void eat() {
        class_3218 world = (class_3218) maid.method_37908();
        if (dealyTick > 0 || slot == -1) {
            return;
        }
        class_1799 stack = maid.getInventory().getItem(slot);
        if (((IItemStack) (Object) stack).isFood()) {
            class_9323 components = stack.method_57353();
            class_4174 foodComponent = components.method_58694(class_9334.field_50075);
            if (foodComponent != null) {
                int nutritionValue = foodComponent.comp_2491();
                int saturationValue = Math.round(foodComponent.comp_2492());
                maid.setNutrition(maid.getNutrition() + nutritionValue);
                maid.setSaturation(maid.getSaturation() + saturationValue);
                stack.method_7934(1);
                world.method_43128(
                        null,
                        maid.method_23317(),
                        maid.method_23318(),
                        maid.method_23321(),
                        class_3417.field_19149,
                        class_3419.field_15256,
                        0.5F,
                        class_3532.method_32750(world.field_9229, 0.9F, 1.0F)
                );
            }
        }
    }

}
